//----------------------------------------------------------------------------
//  Project FastMode
//  
//  Copyright (c) 1997 - 2002, Zeal SoftStudio. All Rights Reserved.
//  E-Mail: support@zealsoftstudio.com
//  Web: http://www.zealsoftstudio.com
//  This sample illustrates how to use the fast mode of
//  NTPort Library to increase performance.
//
//  SUBSYSTEM:    FastMode Application
//  FILE:         fastmodedlgclient.cpp
//  AUTHOR:       Hai Li
//
//  OVERVIEW
//  ~~~~~~~~
//  Source file for implementation of TFastModeDlgClient (TDialog).
//
//----------------------------------------------------------------------------

#include <owl/pch.h>

#include "fastmodeapp.h"
#include "fastmodedlgclient.h"
#include "ntport.h"

//
// Build a response table for all messages/commands handled by the application.
//
DEFINE_RESPONSE_TABLE1(TFastModeDlgClient, TDialog)
//{{TFastModeDlgClientRSP_TBL_BEGIN}}
  EV_BN_CLICKED(IDC_BUTTON1, BNNormalClicked),
  EV_BN_CLICKED(IDC_BUTTON2, BNFastClicked),
//{{TFastModeDlgClientRSP_TBL_END}}
END_RESPONSE_TABLE;


//{{TFastModeDlgClient Implementation}}


//--------------------------------------------------------
// TFastModeDlgClient
// ~~~~~~~~~~
// Construction/Destruction handling.
//
TFastModeDlgClient::TFastModeDlgClient(TWindow* parent, TResId resId, TModule* module)
:
  TDialog(parent, resId, module)
{
  // INSERT>> Your constructor code here.
}


TFastModeDlgClient::~TFastModeDlgClient()
{
  Destroy();

  // INSERT>> Your destructor code here.
}

void TFastModeDlgClient::BNNormalClicked()
{
  // INSERT>> Your code here.
  int i, tTime, nTimes;
  short nData, nPort;
  char sz[30];

  // Using normal mode
  SetFastMode(FALSE);

  // Get the address of the port
  nPort = (short)GetDlgItemInt(IDC_EDIT1);
  nTimes = GetDlgItemInt(IDC_EDIT2);

  // If you are using Evaluation version, this
  // statement will show the registration reminder
  // dialog. If you are using the registered version,
  // please call LicesnseInfo instead.
  nData = Inp(nPort);

  // Test the result of Inp
  if(GetLastState(sz) != ERROR_NONE)
  {
      MessageBox(sz, 0, MB_ICONSTOP);
      return;
  }

  // Start the time count
  tTime = timeGetTime();

  // Read the port in a loop
  for( i = 1; i <= nTimes; i++)
      nData = Inp(nPort);

  // Stop the time count
  tTime = timeGetTime() - tTime;

  // Show the result
  char s[256];
  wsprintf(s, "Normal mode time cost: %dms", tTime);
  SetDlgItemText(IDC_STATICTEXT3, s);
}

void TFastModeDlgClient::BNFastClicked()
{
  // INSERT>> Your code here.
  int i, tTime, nTimes;
  short nData, nPort;
  char sz[30];

  // Check the OS
  if(!IsWinNT())
  {
      MessageBox("Fast mode is designed for Windows NT/2000/XP, not Windows 95/98/Me.",
         0, MB_ICONSTOP);
      return;
  }

  // Using normal mode
  SetFastMode(TRUE);

  // Get the address of the port
  nPort = (short)GetDlgItemInt(IDC_EDIT1);
  nTimes = GetDlgItemInt(IDC_EDIT2);

  // To use the fast mode, you must call EnablePorts
  // before you call the Inport, Outport, and other
  // functions.
  EnablePorts(nPort, nPort);

  // Test the result of EnablePorts
  if(GetLastState(sz) != ERROR_NONE)
  {
      MessageBox(sz, 0, MB_ICONSTOP);
      return;
  }

  // If you are using Evalualtion version, this
  // statement will show the registration reminder
  // dialog. If you are using the registered version,
  // please call LicesnseInfo instead.
  nData = Inp(nPort);

  // Start the time count
  tTime = timeGetTime();

  // Read the port in a loop
  for( i = 1; i <= nTimes; i++)
        nData = Inp(nPort);

  // Stop the time count
  tTime = timeGetTime() - tTime;

  // Free the resource
  DisablePorts(nPort, nPort);

  // Show the result
  char s[256];
  wsprintf(s, "Fast mode time cost: %dms", tTime);
  SetDlgItemText(IDC_STATICTEXT4, s);

}

